==> mono_1.9.1+dfsg.orig.tar.gz: mono-1.9.1+dfsg/mcs/class/corlib/System.Resources/MissingSatelliteAssemblyException.cs <==
//
// System.Resources.MissingSatelliteAssemblyException.cs
//
// Author:
//	Atsushi Enomoto <atsushi@ximian.com>
//

//
// Copyright (C) 2007 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

using System.Globalization;
using System.Runtime.Serialization;

namespace System.Resources
{

	[Serializable]
	[System.Runtime.InteropServices.ComVisible (true)]
	public class MissingSatelliteAssemblyException : SystemException
	{
		private string culture;

		// Constructors
		public MissingSatelliteAssemblyException ()
			: base (Locale.GetText ("The satellite assembly was not found for the required culture."))
		{
		}
		
		public MissingSatelliteAssemblyException (string message)
			:base (message)
		{
		}
		
		public MissingSatelliteAssemblyException (string message, string cultureName)
			:base (message)
		{
		}
		
		protected MissingSatelliteAssemblyException (SerializationInfo info, StreamingContext context)
				    :base (info, context)
		{
		}
		
		public MissingSatelliteAssemblyException (String message, Exception e)
			: base (message, e)
		{
		}

		public string CultureName {
			get { return culture; }
		}
	}
}

#endif

==> mono_2.0.1.orig.tar.gz: mono-2.0.1/mcs/class/corlib/System.Resources/MissingSatelliteAssemblyException.cs <==
//
// System.Resources.MissingSatelliteAssemblyException.cs
//
// Author:
//	Atsushi Enomoto <atsushi@ximian.com>
//

//
// Copyright (C) 2007 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

using System.Globalization;
using System.Runtime.Serialization;

namespace System.Resources
{

	[Serializable]
	[System.Runtime.InteropServices.ComVisible (true)]
	public class MissingSatelliteAssemblyException : SystemException
	{
		private string culture;

		// Constructors
		public MissingSatelliteAssemblyException ()
			: base (Locale.GetText ("The satellite assembly was not found for the required culture."))
		{
		}
		
		public MissingSatelliteAssemblyException (string message)
			:base (message)
		{
		}
		
		public MissingSatelliteAssemblyException (string message, string cultureName)
			:base (message)
		{
		}
		
		protected MissingSatelliteAssemblyException (SerializationInfo info, StreamingContext context)
				    :base (info, context)
		{
		}
		
		public MissingSatelliteAssemblyException (String message, Exception inner)
			: base (message, inner)
		{
		}

		public string CultureName {
			get { return culture; }
		}
	}
}

#endif
